#!/usr/bin/env node

const fs = require('fs');
const path = require('path');


// Directory where the K6 tests will be stored
const k6TestDirectory = './k6-tests';


// Template for the K6 basic test script
const basicTestFile = `
import http from 'k6/http';
import { check, sleep } from 'k6';
import { config } from './config.js';

export const options = {
  vus: __ENV.VUS ? parseInt(__ENV.VUS) : config.VUS,
  duration: __ENV.DURATION ? __ENV.DURATION : config.DURATION,
};

export default function () {
  const url = __ENV.URL ? JSON.parse(__ENV.URL) : config.URL; // Parse URL array
  const method = __ENV.METHOD ? __ENV.METHOD : config.METHOD;
  const payload = __ENV.PAYLOAD ? JSON.parse(__ENV.PAYLOAD) : JSON.parse(config.PAYLOAD);

  // Handle authentication (if required)
const username = __ENV.USERNAME ? __ENV.USERNAME : (config.USERNAME || '');
const password = __ENV.PASSWORD ? __ENV.PASSWORD : (config.PASSWORD || '');

// Initialize authHeader as an empty object
let authHeader = { headers: {} };
let credentials = '';
if (username && password) {
  credentials = \`\${username}:\${password}\`; // Corrected line
  const base64Credentials = Buffer.from(credentials).toString('base64'); // Use Buffer for base64 encoding in Node.js
  authHeader.headers.Authorization = \`Basic \${base64Credentials}\`; // Corrected line
}

// Add Bearer Token if provided
if (__ENV.AUTH_TOKEN) {
  authHeader.headers.Authorization = \`Bearer \${__ENV.AUTH_TOKEN}\`;
}


  // Randomly select a URL from the array
  const selectedUrl = url[Math.floor(Math.random() * url.length)];

  let res;
  if (method === 'POST') {
    res = http.post(selectedUrl, payload, authHeader);
  } else if (method === 'PUT') {
    res = http.put(selectedUrl, payload, authHeader);
  } else {
    // Conditionally pass authHeader if there are authentication details
    res = Object.keys(authHeader.headers).length > 1 ? http.get(selectedUrl, authHeader) : http.get(selectedUrl);
  }

  const expectedStatus = __ENV.STATUS ? parseInt(__ENV.STATUS) : config.STATUS;

  check(res, {
    ['status is ' + expectedStatus]: (r) => r.status === expectedStatus,
  });

  const sleepTime = __ENV.SLEEP ? parseFloat(__ENV.SLEEP) : config.SLEEP;
  sleep(sleepTime);
}

`;

// Template for the config.js file
const configFileContent = `
// config.js
export const config = {
  VUS: 100,  // Number of virtual users
  DURATION: '60s',  // Test duration
  URL: ['https://www.triconinfotech.com/contact/'],  // Array of URLs to test
  METHOD: 'GET',  // Default method (GET, POST, PUT)
  PAYLOAD: JSON.stringify({ name: 'Hrithik' }),  // Default payload for POST/PUT
  STATUS: 200,  // Expected HTTP status
  SLEEP: 1,  // Time to sleep between iterations (in seconds)

  // Optional: Authentication details
  USERNAME: '',  // Replace with actual username
  PASSWORD: '',  // Replace with actual password
  AUTH_TOKEN: '',  // Replace with token if using token-based authentication (e.g., Bearer token)
};

`;

// Template for the generate-report.js file
const generateReportFileContent = `
// generate-report.js
const fs = require('fs');
const path = require('path');

// Function to read JSON results and generate HTML report
function generateHtmlReport() {
  const resultsFilePath = path.join(__dirname, 'results.json');
  const reportFilePath = path.join(__dirname, 'report.html');

  if (!fs.existsSync(resultsFilePath)) {
    console.error('Error: Results file not found. Please run the K6 tests first.');
    return;
  }

  const results = JSON.parse(fs.readFileSync(resultsFilePath, 'utf-8'));

  // Get the total requests and calculate failed requests
  const totalRequests = results.metrics.http_reqs.count;
  const failedRequestsRate = results.metrics.http_req_failed.value || 0; // Failure rate
  const failedRequests = Math.round(failedRequestsRate * totalRequests); // Calculate total failed requests

  // Basic HTML report structure
  let htmlContent = \`
   <!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>K6 Test Report</title>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            background-color: #f4f7f9;
            margin: 0;
            padding: 20px;
            color: #333;
        }

        h1 {
            color: #333;
            text-align: center;
            margin-bottom: 10px;
        }

        h2 {
            color: #666;
            text-align: center;
            margin-bottom: 20px;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            margin-bottom: 20px;
            background-color: #fff;
        }

        th, td {
            border: 1px solid #ddd;
            padding: 12px 15px;
            text-align: left;
        }

        th {
            background-color: #007bff;
            color: #fff;
            font-weight: bold;
        }

        tr:nth-child(even) {
            background-color: #f9f9f9;
        }

        tr:hover {
            background-color: #f1f1f1;
        }

        td {
            transition: background-color 0.2s ease;
        }

        @media (max-width: 600px) {
            table, th, td {
                display: block;
                width: 100%;
            }

            th {
                position: absolute;
                top: -9999px;
                left: -9999px;
            }

            tr {
                margin-bottom: 10px;
            }

            td {
                text-align: right;
                padding-left: 50%;
                position: relative;
            }

            td::before {
                content: attr(data-label);
                position: absolute;
                left: 10px;
                text-align: left;
                font-weight: bold;
                color: #555;
            }
        }
    </style>
</head>
<body>
    <h1>K6 Test Report</h1>
    <h2>Summary</h2>
    <table>
        <tr>
            <th>Metric</th>
            <th>Value</th>
        </tr>
        <tr>
            <td data-label="Metric">Total Requests</td>
            <td data-label="Value">${totalRequests}</td>
        </tr>
        <tr>
            <td data-label="Metric">Failed Requests</td>
            <td data-label="Value">${failedRequests}</td>
        </tr>
        <tr>
            <td data-label="Metric">Average Response Time</td>
            <td data-label="Value">${results.metrics.http_req_duration.avg.toFixed(2)} ms</td>
        </tr>
        <tr>
            <td data-label="Metric">Median Response Time</td>
            <td data-label="Value">${results.metrics.http_req_duration.med.toFixed(2)} ms</td>
        </tr>
        <tr>
            <td data-label="Metric">Max Response Time</td>
            <td data-label="Value">${results.metrics.http_req_duration.max.toFixed(2)} ms</td>
        </tr>
        <tr>
            <td data-label="Metric">Min Response Time</td>
            <td data-label="Value">${results.metrics.http_req_duration.min.toFixed(2)} ms</td>
        </tr>
        <tr>
            <td data-label="Metric">90th Percentile Response Time</td>
            <td data-label="Value">${results.metrics.http_req_duration['p(90)'].toFixed(2)} ms</td>
        </tr>
        <tr>
            <td data-label="Metric">95th Percentile Response Time</td>
            <td data-label="Value">${results.metrics.http_req_duration['p(95)'].toFixed(2)} ms</td>
        </tr>
        <tr>
            <td data-label="Metric">Data Sent</td>
            <td data-label="Value">${results.metrics.data_sent.count} bytes</td>
        </tr>
        <tr>
            <td data-label="Metric">Data Received</td>
            <td data-label="Value">${results.metrics.data_received.count} bytes</td>
        </tr>
        <tr>
            <td data-label="Metric">Number of Iterations</td>
            <td data-label="Value">${results.metrics.iterations.count}</td>
        </tr>
        <tr>
            <td data-label="Metric">Virtual Users (Max)</td>
            <td data-label="Value">${results.metrics.vus_max.value}</td>
        </tr>
        <tr>
            <td data-label="Metric">Checks Passed</td>
            <td data-label="Value">${results.metrics.checks.passes}</td>
        </tr>
        <tr>
            <td data-label="Metric">Checks Failed</td>
            <td data-label="Value">${results.metrics.checks.fails}</td>
        </tr>
    </table>
</body>
</html>

  \`;

  // Write the HTML report to a file
  fs.writeFileSync(reportFilePath, htmlContent);
  console.log('Generated HTML report: report.html');
}

// Execute the report generation
generateHtmlReport();
`;

// Function to create the directory for K6 tests if it doesn't exist
function createK6TestDirectory(directoryPath) {
  if (!fs.existsSync(directoryPath)) {
    fs.mkdirSync(directoryPath);
    console.log(`Created directory: ${directoryPath}`);
  } else {
    console.log(`Directory already exists: ${directoryPath}`);
  }
}

// Function to write the K6 test script to the file system
function createK6TestScript(filePath, content) {
  if (!fs.existsSync(filePath)) {
    fs.writeFileSync(filePath, content);
    console.log(`Created K6 basic test script: ${filePath}`);
  } else {
    console.log(`K6 test script already exists: ${filePath}`);
  }
}

// Function to create the config.js file
function createConfigFile(filePath, content) {
  if (!fs.existsSync(filePath)) {
    fs.writeFileSync(filePath, content);
    console.log(`Created config file: ${filePath}`);
  } else {
    console.log(`Config file already exists: ${filePath}`);
  }
}

// Function to create the generate-report.js file
function createGenerateReportFile(filePath, content) {
  if (!fs.existsSync(filePath)) {
    fs.writeFileSync(filePath, content);
    console.log(`Created report generation script: ${filePath}`);
  } else {
    console.log(`Report generation script already exists: ${filePath}`);
  }
}

// Main function to set up the basic K6 test structure and config file
function setupK6Test() {
  createK6TestDirectory(k6TestDirectory);
  createK6TestScript(path.join(k6TestDirectory, 'basicTest.js'), basicTestFile);
  createConfigFile(path.join(k6TestDirectory, 'config.js'), configFileContent);
  createGenerateReportFile(path.join(k6TestDirectory, 'generate-report.js'), generateReportFileContent);
  console.log('No Go dependency required for this setup.');

  // Optionally, you can execute the K6 test here and then generate the report
  // This assumes you have a way to run K6 tests programmatically, which might require additional setup.
  // Uncomment below if you want to run K6 test after setup.
  /*
  const { exec } = require('child_process');
  exec('k6 run ./k6-tests/basicTest.js', (error, stdout, stderr) => {
    if (error) {
      console.error(\`Error running K6 tests: \${error.message}\`);
      return;
    }
    if (stderr) {
      console.error(\`K6 stderr: \${stderr}\`);
      return;
    }
    console.log(\`K6 stdout: \${stdout}\`);

    // After K6 tests run, generate the report
    require(path.join(k6TestDirectory, 'generate-report.js'));
  });
  */
}

// Run the setup process
setupK6Test();
// #!/usr/bin/env node

// const fs = require('fs');
// const path = require('path');
// const { execSync } = require('child_process');

// // Directory where the K6 tests will be stored
// const k6TestDirectory = './k6-tests';

// // Template for the K6 basic test script
// const basicTestFile = `
// // K6 test script content
// import http from 'k6/http';
// import { check, sleep } from 'k6';
// import { config } from './config.js';

// export const options = {
//   vus: __ENV.VUS ? parseInt(__ENV.VUS) : config.VUS,
//   duration: __ENV.DURATION ? __ENV.DURATION : config.DURATION,
// };

// export default function () {
//   const url = __ENV.URL ? __ENV.URL : config.URL;
//   const method = __ENV.METHOD ? __ENV.METHOD : config.METHOD;
//   const payload = __ENV.PAYLOAD ? JSON.parse(__ENV.PAYLOAD) : JSON.parse(config.PAYLOAD);

//   let res;
//   if (method === 'POST') {
//     res = http.post(url, payload);
//   } else if (method === 'PUT') {
//     res = http.put(url, payload);
//   } else {
//     res = http.get(url);
//   }

//   const expectedStatus = __ENV.STATUS ? parseInt(__ENV.STATUS) : config.STATUS;
//   check(res, { [\`status is \${expectedStatus}\`]: (r) => r.status === expectedStatus });

//   const sleepTime = __ENV.SLEEP ? parseFloat(__ENV.SLEEP) : config.SLEEP;
//   sleep(sleepTime);
// }
// `;

// // Template for the config.js file
// const configFileContent = `
// export const config = {
//   VUS: 10,
//   DURATION: '30s',
//   URL: 'https://hkt9137.netlify.app/',
//   METHOD: 'POST',
//   PAYLOAD: JSON.stringify({ name: 'Hrithik' }),
//   STATUS: 201,
//   SLEEP: 1
// };
// `;

// // Function to create the directory for K6 tests if it doesn't exist
// function createK6TestDirectory(directoryPath) {
//   if (!fs.existsSync(directoryPath)) {
//     fs.mkdirSync(directoryPath);
//     console.log(`Created directory: ${directoryPath}`);
//   } else {
//     console.log(`Directory already exists: ${directoryPath}`);
//   }
// }

// // Function to write the K6 test script to the file system
// function createK6TestScript(filePath, content) {
//   if (!fs.existsSync(filePath)) {
//     fs.writeFileSync(filePath, content);
//     console.log(`Created K6 basic test script: ${filePath}`);
//   } else {
//     console.log(`K6 test script already exists: ${filePath}`);
//   }
// }

// // Function to create the config.js file
// function createConfigFile(filePath, content) {
//   if (!fs.existsSync(filePath)) {
//     fs.writeFileSync(filePath, content);
//     console.log(`Created config file: ${filePath}`);
//   } else {
//     console.log(`Config file already exists: ${filePath}`);
//   }
// }

// // Function to install k6-html package
// function installK6HtmlPackage() {
//   try {
//     execSync('go get -u github.com/ValentinGonzalez/k6-html', { stdio: 'inherit' });
//     console.log('Installed k6-html package.');
//   } catch (error) {
//     console.error('Failed to install k6-html package:', error);
//   }
// }

// // Main function to set up the basic K6 test structure and config file
// function setupK6Test() {
//   createK6TestDirectory(k6TestDirectory);
//   createK6TestScript(path.join(k6TestDirectory, 'basicTest.js'), basicTestFile);
//   createConfigFile(path.join(k6TestDirectory, 'config.js'), configFileContent);
//   installK6HtmlPackage();  // Install the package for HTML reporting
// }

// // Run the setup process
// setupK6Test();




// #!/usr/bin/env node

// const fs = require('fs');
// const path = require('path');

// // Directory where the K6 tests will be stored
// const k6TestDirectory = './k6-tests';

// // Template for the K6 basic test script with values from config.js
// const basicTestFile = `
// import http from 'k6/http';
// import { check, sleep } from 'k6';
// import { config } from './config.js';   // Import config file

// export const options = {
//   vus: __ENV.VUS ? parseInt(__ENV.VUS) : config.VUS,               // Number of Virtual Users
//   duration: __ENV.DURATION ? __ENV.DURATION : config.DURATION,     // Duration of the test
// };

// export default function () {
//   const url = __ENV.URL ? __ENV.URL : config.URL;
//   const method = __ENV.METHOD ? __ENV.METHOD : config.METHOD; // HTTP method
//   const payload = __ENV.PAYLOAD ? JSON.parse(__ENV.PAYLOAD) : JSON.parse(config.PAYLOAD); // Payload for POST/PUT

//   let res;
//   if (method === 'POST') {
//     res = http.post(url, payload);
//   } else if (method === 'PUT') {
//     res = http.put(url, payload);
//   } else {
//     res = http.get(url);
//   }

//   const expectedStatus = __ENV.STATUS ? parseInt(__ENV.STATUS) : config.STATUS;
//   check(res, { [\`status is \${expectedStatus}\`]: (r) => r.status === expectedStatus });

//   const sleepTime = __ENV.SLEEP ? parseFloat(__ENV.SLEEP) : config.SLEEP;
//   sleep(sleepTime);
// }
// `;

// // Template for the config.js file
// const configFileContent = `
// export const config = {
//   VUS: 10,
//   DURATION: '30s',
//   URL: 'https://hkt9137.netlify.app/',
//   METHOD: 'POST',
//   PAYLOAD: JSON.stringify({ name: 'Hrithik' }),
//   STATUS: 201,
//   SLEEP: 1
// };
// `;

// // Function to create the directory for K6 tests if it doesn't exist
// function createK6TestDirectory(directoryPath) {
//   if (!fs.existsSync(directoryPath)) {
//     fs.mkdirSync(directoryPath);
//     console.log(`Created directory: ${directoryPath}`);
//   } else {
//     console.log(`Directory already exists: ${directoryPath}`);
//   }
// }

// // Function to write the K6 test script to the file system
// function createK6TestScript(filePath, content) {
//   if (!fs.existsSync(filePath)) {
//     fs.writeFileSync(filePath, content);
//     console.log(`Created K6 basic test script: ${filePath}`);
//   } else {
//     console.log(`K6 test script already exists: ${filePath}`);
//   }
// }

// // Function to create the config.js file
// function createConfigFile(filePath, content) {
//   if (!fs.existsSync(filePath)) {
//     fs.writeFileSync(filePath, content);
//     console.log(`Created config file: ${filePath}`);
//   } else {
//     console.log(`Config file already exists: ${filePath}`);
//   }
// }

// // Main function to set up the basic K6 test structure and config file
// function setupK6Test() {
//   createK6TestDirectory(k6TestDirectory);
//   createK6TestScript(path.join(k6TestDirectory, 'basicTest.js'), basicTestFile);
//   createConfigFile(path.join(k6TestDirectory, 'config.js'), configFileContent);  // Create config.js file
// }

// // Run the setup process
// setupK6Test();




// #!/usr/bin/env node

// const fs = require('fs');
// const path = require('path');

// // Import user-defined config
// const { config } = require('./config');

// // Directory where the K6 tests will be stored
// const k6TestDirectory = './k6-tests';

// // Template for the K6 basic test script with values from config.js
// const basicTestFile = `
// import http from 'k6/http';
// import { check, sleep } from 'k6';
// import { config } from '../config';  // Import config file

// // Set default values that can be overridden by environment variables
// export const options = {
//   vus: __ENV.VUS ? parseInt(__ENV.VUS) : config.VUS,               // Number of Virtual Users
//   duration: __ENV.DURATION ? __ENV.DURATION : config.DURATION,       // Duration of the test
// };

// export default function () {
//   const url = __ENV.URL ? __ENV.URL : config.URL;
//   const method = __ENV.METHOD ? __ENV.METHOD : config.METHOD; // HTTP method
//   const payload = __ENV.PAYLOAD ? JSON.parse(__ENV.PAYLOAD) : JSON.parse(config.PAYLOAD); // Payload for POST/PUT

//   let res;
//   if (method === 'POST') {
//     res = http.post(url, payload);
//   } else if (method === 'PUT') {
//     res = http.put(url, payload);
//   } else {
//     res = http.get(url);
//   }

//   const expectedStatus = __ENV.STATUS ? parseInt(__ENV.STATUS) : config.STATUS;
//   check(res, { [\`status is \${expectedStatus}\`]: (r) => r.status === expectedStatus });

//   const sleepTime = __ENV.SLEEP ? parseFloat(__ENV.SLEEP) : config.SLEEP;
//   sleep(sleepTime);
// }
// `;

// // Function to create the directory for K6 tests if it doesn't exist
// function createK6TestDirectory(directoryPath) {
//   if (!fs.existsSync(directoryPath)) {
//     fs.mkdirSync(directoryPath);
//     console.log(`Created directory: ${directoryPath}`);
//   } else {
//     console.log(`Directory already exists: ${directoryPath}`);
//   }
// }

// // Function to write the K6 test script to the file system
// function createK6TestScript(filePath, content) {
//   if (!fs.existsSync(filePath)) {
//     fs.writeFileSync(filePath, content);
//     console.log(`Created K6 basic test script: ${filePath}`);
//   } else {
//     console.log(`K6 test script already exists: ${filePath}`);
//   }
// }

// // Main function to set up the basic K6 test structure
// function setupK6Test() {
//   createK6TestDirectory(k6TestDirectory);
//   createK6TestScript(path.join(k6TestDirectory, 'basicTest.js'), basicTestFile);
// }

// // Run the setup process
// setupK6Test();


// #!/usr/bin/env node

// const fs = require('fs');
// const path = require('path');

// // Directory where the K6 tests will be stored
// const k6TestDirectory = './k6-tests';

// // Template for the K6 basic test script
// const basicTestFile = `import http from 'k6/http';
// import { check, sleep } from 'k6';

// // Set default values that can be overridden by environment variables
// export const options = {
//   vus: __ENV.VUS ? parseInt(__ENV.VUS) : 10,               // Number of Virtual Users
//   duration: __ENV.DURATION ? __ENV.DURATION : '30s',       // Duration of the test
// };

// export default function () {
//   const url = __ENV.URL ? __ENV.URL : 'https://test-api.k6.io/';
//   const method = __ENV.METHOD ? __ENV.METHOD : 'GET'; // HTTP method
//   const payload = __ENV.PAYLOAD ? JSON.parse(__ENV.PAYLOAD) : null; // Payload for POST/PUT

//   let res;
//   if (method === 'POST') {
//     res = http.post(url, payload);
//   } else if (method === 'PUT') {
//     res = http.put(url, payload);
//   } else {
//     res = http.get(url);
//   }

//   const expectedStatus = __ENV.STATUS ? parseInt(__ENV.STATUS) : 200;
//   check(res, { [\`status is \${expectedStatus}\`]: (r) => r.status === expectedStatus });

//   const sleepTime = __ENV.SLEEP ? parseFloat(__ENV.SLEEP) : 1;
//   sleep(sleepTime);
// }
// `;

// // Function to create the directory for K6 tests if it doesn't exist
// function createK6TestDirectory(directoryPath) {
//   if (!fs.existsSync(directoryPath)) {
//     fs.mkdirSync(directoryPath);
//     console.log(`Created directory: ${directoryPath}`);
//   } else {
//     console.log(`Directory already exists: ${directoryPath}`);
//   }
// }

// // Function to write the K6 test script to the file system
// function createK6TestScript(filePath, content) {
//   if (!fs.existsSync(filePath)) {
//     fs.writeFileSync(filePath, content);
//     console.log(`Created K6 basic test script: ${filePath}`);
//   } else {
//     console.log(`K6 test script already exists: ${filePath}`);
//   }
// }

// // Main function to set up the basic K6 test structure
// function setupK6Test() {
//   createK6TestDirectory(k6TestDirectory);
//   createK6TestScript(path.join(k6TestDirectory, 'basicTest.js'), basicTestFile);
// }

// // Run the setup process
// setupK6Test();





// #!/usr/bin/env node

// const fs = require('fs');
// const path = require('path');

// // Directory where the K6 tests will be stored
// const k6TestDirectory = './k6-tests';

// // Template for the K6 basic test script
// const basicTestFile = `import http from 'k6/http';
// import { check, sleep } from 'k6';

// // Set default values that can be overridden by environment variables
// export const options = {
//   vus: __ENV.VUS ? parseInt(__ENV.VUS) : 10,               // Number of Virtual Users
//   duration: __ENV.DURATION ? __ENV.DURATION : '30s',       // Duration of the test
// };

// export default function () {
//   // Use environment variable for the URL or default to the K6 test API
//   const url = __ENV.URL ? __ENV.URL : 'https://test-api.k6.io/';
//   const res = http.get(url);

//   // Check the response status, defaulting to 200 if not provided
//   const expectedStatus = __ENV.STATUS ? parseInt(__ENV.STATUS) : 200;
//   check(res, { [\`status is \${expectedStatus}\`]: (r) => r.status === expectedStatus });

//   // Sleep for a dynamic amount of time, defaulting to 1 second
//   const sleepTime = __ENV.SLEEP ? parseFloat(__ENV.SLEEP) : 1;
//   sleep(sleepTime);
// }
// `;

// // Function to create the directory for K6 tests if it doesn't exist
// function createK6TestDirectory(directoryPath) {
//   if (!fs.existsSync(directoryPath)) {
//     fs.mkdirSync(directoryPath);
//     console.log(`Created directory: ${directoryPath}`);
//   } else {
//     console.log(`Directory already exists: ${directoryPath}`);
//   }
// }

// // Function to write the K6 test script to the file system
// function createK6TestScript(filePath, content) {
//   if (!fs.existsSync(filePath)) {
//     fs.writeFileSync(filePath, content);
//     console.log(`Created K6 basic test script: ${filePath}`);
//   } else {
//     console.log(`K6 test script already exists: ${filePath}`);
//   }
// }

// // Main function to set up the basic K6 test structure
// function setupK6Test() {
//   createK6TestDirectory(k6TestDirectory);
//   createK6TestScript(path.join(k6TestDirectory, 'basicTest.js'), basicTestFile);
// }

// // Run the setup process
// setupK6Test();
// // module.exports = {
// //   setupK6Test
// // };


// // #!/usr/bin/env node
// // const fs = require('fs');
// // const path = require('path');

// // const k6TestDirectory = './k6-tests';
// // const basicTestFile = `import http from 'k6/http';
// // import { check, sleep } from 'k6';

// // // Setting default values, which can be overridden by environment variables
// // export const options = {
// //   vus: __ENV.VUS ? parseInt(__ENV.VUS) : 10,               // Number of Virtual Users
// //   duration: __ENV.DURATION ? __ENV.DURATION : '30s',       // Duration of the test
// // };

// // export default function () {
// //   // Using environment variable for the URL or defaulting to the K6 test API
// //   const url = __ENV.URL ? __ENV.URL : 'https://test-api.k6.io/';
// //   const res = http.get(url);

// //   // Check the response status, defaulting to 200 if not specified
// //   const expectedStatus = __ENV.STATUS ? parseInt(__ENV.STATUS) : 200;
// //   check(res, { [\`status is \${expectedStatus}\`]: (r) => r.status === expectedStatus });

// //   // Sleep for a dynamic amount of time, defaulting to 1 second
// //   const sleepTime = __ENV.SLEEP ? parseFloat(__ENV.SLEEP) : 1;
// //   sleep(sleepTime);
// // }
// // `;

// // // Create the directory for K6 tests if it doesn't exist
// // if (!fs.existsSync(k6TestDirectory)) {
// //   fs.mkdirSync(k6TestDirectory);
// //   console.log(`Created directory: ${k6TestDirectory}`);
// // }

// // // Write the basic K6 test file
// // fs.writeFileSync(path.join(k6TestDirectory, 'basicTest.js'), basicTestFile);
// // console.log('Created K6 basic test script: k6-tests/basicTest.js');


